@@ -1,6 +1,6 @@
 use blue_engine::{
     header::{uniform_type::Matrix, Engine, RotateAxis, WindowDescriptor},
-    objects::{square, triangle},
+    objects::two_dimensions::{square, triangle},
     utils::text::Text,
 };
 
@@ -14,15 +14,15 @@ fn main() {
     })
     .expect("win");
 
-    /*let mut font = Text::new(
+    let mut font = Text::new(
         include_bytes!("resource/JetBrainsMono-Medium.ttf"),
-        13f32,
+        25f32,
         &mut engine.renderer
     )
-    .unwrap();*/
+    .unwrap();
 
     //let triangle_id = triangle(Some("Triangleee"), &mut engine, camera).unwrap();
-    let square_id = square(Some("SQUAREEE"), &mut engine).unwrap();
+    //let square_id = square(Some("SQUAREEE"), &mut engine).unwrap();
     let window_size = engine.window.inner_size();
     /*let change_texture = engine
         .renderer
@@ -34,7 +34,7 @@ fn main() {
         )
         .unwrap();*/
 
-    let square = engine.get_object(square_id).unwrap();
+    //let square = engine.get_object(square_id).unwrap();
     //square.change_color(0.0, 0.0, 1.0, 0.7).unwrap();
     //square.change_texture(change_texture);
     //square.resize(100.0, 100.0, 0.0, window_size);
@@ -42,7 +42,7 @@ fn main() {
     //let square = engine.objects.get_mut(square_id).unwrap();
 
     //square.no_stretch_update(&mut engine.renderer, engine.window.inner_size()).unwrap();
-    //font.draw("H", (50, 50), &mut engine).unwrap();
+    font.draw("Hello_World", (-100, 50), &mut engine).unwrap();
 
     let radius = 2f32;
     let start = std::time::SystemTime::now();
@@ -54,25 +54,7 @@ fn main() {
             let camz = glm::cos(start.elapsed().unwrap().as_secs_f32()) * radius;
             //camera.set_eye([camx, 0.0, camz]);
 
-            if events.mouse_pressed(0) {
-                let square = objects.get_mut(square_id).unwrap();
-                square.position(10.0, 10.0, 0.0, window.inner_size());
-                square.change_color(0.0, 1.0, 0.0, 0.7).unwrap();
-            }
-            if events.mouse_pressed(1) {
-                let square = objects.get_mut(square_id).unwrap();
-                square.position(100.0, 100.0, 0.0, window.inner_size());
-                square.change_color(1.0, 0.0, 0.0, 0.7).unwrap();
-            }
-            if events.mouse_pressed(2) {
-                let square = objects.get_mut(square_id).unwrap();
-                square.position(0.0, 0.0, 0.0, window.inner_size());
-                //square.change_color(0.0, 0.0, 1.0, 0.7).unwrap();
-
-                rotation += 0.5;
-                println!("rotation: {}", rotation);
-                square.rotate(rotation, RotateAxis::Z);
-            }
+            
         })
         .expect("Error during update loop");
 }
