@@ -4,16 +4,10 @@
  * The license is same as the one on the root.
 */
 
-use blue_engine::{
-    header::{Engine, WindowDescriptor, Vertex},
-};
+use blue_engine::header::{Engine, ObjectSettings, Vertex, WindowDescriptor};
 
-pub fn square(
-    name: Option<&'static str>,
-    engine: &mut Engine,
-) -> Result<usize, anyhow::Error> {
+pub fn square(name: Option<&'static str>, engine: &mut Engine) -> Result<usize, anyhow::Error> {
     let new_square = engine.new_object(
-        name,
         vec![
             Vertex {
                 position: [1.0, 1.0, 0.0],
@@ -33,14 +27,17 @@ pub fn square(
             },
         ],
         vec![2, 1, 0, 2, 0, 3],
+        ObjectSettings {
+            name: name,
+            ..Default::default()
+        },
     )?;
 
     Ok(new_square)
 }
 
 fn main() {
-    let mut engine = Engine::new(WindowDescriptor::default())
-    .expect("win");
+    let mut engine = Engine::new(WindowDescriptor::default()).expect("win");
 
     let _ = square(Some("Square"), &mut engine).unwrap();
 
